/* sas_syntax */
/* recodes and transformations */ 
data marsh;
 set marsh;

if landnummer in (1,4,8,12,16) then land1=1; /* old ms */
if landnummer in (3,9,13,14)   then land1=2; /* CEE    */
if landnummer in (6,11)        then land1=3; /* South  */
if landnummer in (15,7,5)      then land1=4; /* North  */

if landnummer in (1,4,16,6)   then feder = 1; /* regionalized */
else                               feder = 0;

if rep_level eq 0     then pr=0;
if rep_level eq 1     then pr=1;
if rep_level in (2,3) then pr=2;

if pr eq 2 then pr2 = 1;
if pr eq 1 then pr2 = 0;

totaltiesln=log(totalties);
affiliationln=log(affiliations);

if d_ec  eq . then deal_ec  = 2; else if d_ec  le 2 then deal_ec  = 1; if d_ec  gt 2 then deal_ec = 0; 
if d_ep  eq . then deal_ep  = 2; else if d_ep  le 2 then deal_ep  = 1; if d_ep  gt 2 then deal_ep = 0; 
if d_gov eq . then deal_gov = 2; else if d_gov le 2 then deal_gov = 1; if d_gov gt 2 then deal_gov = 0; 

if deal_ec  eq 2 then deal_ec  = 0;
if deal_ep  eq 2 then deal_ep  = 0;
if deal_gov eq 2 then deal_gov = 0;

run; 

proc sort data=marsh;
proc freq;
 tables deal_ec deal_ep deal_gov;
run;

proc corr; 
 var pr2 DG_issue_d3 EUP_RAP COMH_is_D;
run;

/* coding distances */
proc means data=marsh mean median std min max maxdec=2; var d_ec d_ep d_gov;     
proc means data=marsh mean median std min max maxdec=2; var d_ec d_ep d_gov;     
class topic; 
run;

/* table appendix */
/* number of expert interviews with regional offices */ 
/* distribution specific policy processes */
proc freq data=marsh;
 tables landnummer*polproc_cap landnummer*polproc_hor landnummer*polproc_reg landnummer*polproc_tent/nopercent nocum norow nocol;

/* total number of cases in which we interviewed experts */
proc freq data=marsh;
 tables landnummer*issue_nr landnummer*org;

/* table 2 */
proc means data=marsh mean std min max maxdec=2;
 var staffln sr_v5 e_i affiliationln totaltiesln deal_ec deal_ep deal_gov polproc_cap polproc_hor polproc_tent polproc_reg;     
run;

/* coding distances */
proc means data=marsh mean median std min max maxdec=2; var d_ec d_ep d_gov;  
run; 
proc means data=marsh mean median std min max maxdec=2; var d_ec d_ep d_gov;     
class issue_nr; 
run;

/* percentages for figure 1 */
proc freq data=marsh;
 tables COMH_TOT_d COMH_is_D DG_TOT_d DG_issue_d3 EUP_RAP REP_LEVEL_d COREPER REP_level;

/* table 3; clustering of the data */
/* see separate syntax */

/* logistic regression analysis */
 /* pr */
 proc genmod data=marsh;  /* null-model */
 class landnummer;
 model pr2 = /dist = bin type3 wald
 link = logit
 lrci;
 repeated subject=landnummer / type=ind printmle; 
run cancel;

proc genmod data=marsh;
 class landnummer deal_ec deal_ep deal_gov polproc_cap polproc_hor polproc_tent;
 model pr2 = staffln sr_v5 e_i affiliationln totaltiesln deal_ec deal_ep deal_gov polproc_cap polproc_hor polproc_tent/
 dist = bin type3 wald
 link = logit
 lrci;
 repeated subject=landnummer / type=ind printmle; 
run;

/* DG */
proc genmod data=marsh; /* null-model */
 class landnummer;
 model DG_issue_d3 = / dist = bin type3 wald
 link = logit
 lrci;
 repeated subject=landnummer / type=ind; 
run cancel;

proc genmod data=marsh descending;
 class landnummer deal_ec deal_ep deal_gov;
 model DG_issue_d3 = staffln sr_v5 e_i affiliationln totaltiesln deal_ec deal_ep deal_gov polproc_cap polproc_hor polproc_tent/ 
 dist = bin type3 wald
 link = logit
 lrci;
 repeated subject=landnummer / type=ind; 
run;

proc genmod data=marsh;
 class landnummer;
 model DG_issue_d3 = staffln sr_v5 e_i affiliationln totaltiesln polproc_cap polproc_hor polproc_tent/ 
 dist = bin type3 wald
 link = logit
 lrci;
 repeated subject=landnummer / type=ind; 
run cancel;

/* EP */
proc genmod data=marsh; /* null-model */
 class landnummer;
 model eup_rap = /dist = bin type3 wald
 link = logit
 lrci;
 repeated subject=landnummer / type=ind; 
run cancel;

proc genmod data=marsh descending;
 class landnummer deal_ec deal_ep deal_gov;
 model eup_rap = staffln sr_v5 e_i affiliationln totaltiesln deal_ec deal_ep deal_gov polproc_cap polproc_hor polproc_tent/ 
 dist = bin type3 wald
 link = logit
 lrci;
 repeated subject=landnummer / type=ind; 
run;

/* Commissie */
proc genmod data=marsh; /* null-model */
 class landnummer;
 model COMH_is_D = /dist = bin type3 wald
 link = logit
 lrci;
 repeated subject=landnummer / type=ind; 
run cancel;

proc genmod data=marsh descending;
 class landnummer deal_ec deal_ep deal_gov polproc_hor;
 model COMH_is_D = staffln sr_v5 e_i affiliationln totaltiesln deal_ec deal_ep deal_gov polproc_cap polproc_hor polproc_tent/ 
 dist = bin type3 wald
 link = logit
 lrci;
 repeated subject=landnummer / type=ind; 
run;

